==> config-api-0.4.3-sources.jar: org/wildfly/swarm/config/jgroups/stack/Transport.java <==
package org.wildfly.swarm.config.jgroups.stack;

import org.wildfly.swarm.config.runtime.Address;
import java.util.HashMap;
import org.wildfly.swarm.config.runtime.ResourceType;
import java.beans.PropertyChangeSupport;
import java.beans.PropertyChangeListener;
import java.util.List;
import org.wildfly.swarm.config.runtime.Subresource;
import org.wildfly.swarm.config.jgroups.PropertyConsumer;
import org.wildfly.swarm.config.jgroups.PropertySupplier;
import org.wildfly.swarm.config.jgroups.Property;
import org.wildfly.swarm.config.jgroups.stack.transport.OobThreadPool;
import org.wildfly.swarm.config.jgroups.stack.transport.OobThreadPoolConsumer;
import org.wildfly.swarm.config.jgroups.stack.transport.OobThreadPoolSupplier;
import org.wildfly.swarm.config.jgroups.stack.transport.InternalThreadPool;
import org.wildfly.swarm.config.jgroups.stack.transport.InternalThreadPoolConsumer;
import org.wildfly.swarm.config.jgroups.stack.transport.InternalThreadPoolSupplier;
import org.wildfly.swarm.config.jgroups.stack.transport.DefaultThreadPool;
import org.wildfly.swarm.config.jgroups.stack.transport.DefaultThreadPoolConsumer;
import org.wildfly.swarm.config.jgroups.stack.transport.DefaultThreadPoolSupplier;
import org.wildfly.swarm.config.jgroups.stack.transport.TimerThreadPool;
import org.wildfly.swarm.config.jgroups.stack.transport.TimerThreadPoolConsumer;
import org.wildfly.swarm.config.jgroups.stack.transport.TimerThreadPoolSupplier;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import java.util.Map;
/**
 * The configuration of a transport for a protocol stack.
 */
@Address("/subsystem=jgroups/stack=*/transport=*")
@ResourceType("transport")
public class Transport<T extends Transport<T>> extends HashMap {

	private String key;
	private PropertyChangeSupport pcs;
	private TransportResources subresources = new TransportResources();
	private String diagnosticsSocketBinding;
	private String machine;
	private String module;
	private Map properties;
	private String rack;
	private String site;
	private String socketBinding;

	public Transport(String key) {
		super();
		this.key = key;
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * Adds a property change listener
	 */
	public void addPropertyChangeListener(PropertyChangeListener listener) {
		if (null == this.pcs)
			this.pcs = new PropertyChangeSupport(this);
		this.pcs.addPropertyChangeListener(listener);
	}

	/**
	 * Removes a property change listener
	 */
	public void removePropertyChangeListener(PropertyChangeListener listener) {
		if (this.pcs != null)
			this.pcs.removePropertyChangeListener(listener);
	}

	public TransportResources subresources() {
		return this.subresources;
	}

	/**
	 * Add all Property objects to this subresource
	 * 
	 * @return this
	 * @param value
	 *            List of Property objects.
	 */
	@SuppressWarnings("unchecked")
	public T properties(List<Property> value) {
		this.subresources.properties = value;
		return (T) this;
	}

	/**
	 * Add the Property object to the list of subresources
	 * 
	 * @param value
	 *            The Property to add
	 * @return this
	 */
	@SuppressWarnings("unchecked")
	public T property(Property value) {
		this.subresources.properties.add(value);
		return (T) this;
	}

	/**
	 * Create and configure a Property object to the list of subresources
	 * 
	 * @param key
	 *            The key for the Property resource
	 * @param config
	 *            The PropertyConsumer to use
	 * @return this
	 */
	@SuppressWarnings("unchecked")
	public T property(String childKey, PropertyConsumer consumer) {
		Property<? extends Property> child = new Property<>(childKey);
		if (consumer != null) {
			consumer.accept(child);
		}
		property(child);
		return (T) this;
	}

	/**
	 * Create and configure a Property object to the list of subresources
	 * 
	 * @param key
	 *            The key for the Property resource
	 * @return this
	 */
	@SuppressWarnings("unchecked")
	public T property(String childKey) {
		property(childKey, null);
		return (T) this;
	}

	/**
	 * Install a supplied Property object to the list of subresources
	 */
	@SuppressWarnings("unchecked")
	public T property(PropertySupplier supplier) {
		property(supplier.get());
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T oobThreadPool(OobThreadPool value) {
		this.subresources.oobThreadPool = value;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T oobThreadPool(OobThreadPoolConsumer consumer) {
		OobThreadPool<? extends OobThreadPool> child = new OobThreadPool<>();
		if (consumer != null) {
			consumer.accept(child);
		}
		this.subresources.oobThreadPool = child;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T oobThreadPool() {
		OobThreadPool<? extends OobThreadPool> child = new OobThreadPool<>();
		this.subresources.oobThreadPool = child;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T oobThreadPool(OobThreadPoolSupplier supplier) {
		this.subresources.oobThreadPool = supplier.get();
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T internalThreadPool(InternalThreadPool value) {
		this.subresources.internalThreadPool = value;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T internalThreadPool(InternalThreadPoolConsumer consumer) {
		InternalThreadPool<? extends InternalThreadPool> child = new InternalThreadPool<>();
		if (consumer != null) {
			consumer.accept(child);
		}
		this.subresources.internalThreadPool = child;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T internalThreadPool() {
		InternalThreadPool<? extends InternalThreadPool> child = new InternalThreadPool<>();
		this.subresources.internalThreadPool = child;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T internalThreadPool(InternalThreadPoolSupplier supplier) {
		this.subresources.internalThreadPool = supplier.get();
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T defaultThreadPool(DefaultThreadPool value) {
		this.subresources.defaultThreadPool = value;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T defaultThreadPool(DefaultThreadPoolConsumer consumer) {
		DefaultThreadPool<? extends DefaultThreadPool> child = new DefaultThreadPool<>();
		if (consumer != null) {
			consumer.accept(child);
		}
		this.subresources.defaultThreadPool = child;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T defaultThreadPool() {
		DefaultThreadPool<? extends DefaultThreadPool> child = new DefaultThreadPool<>();
		this.subresources.defaultThreadPool = child;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T defaultThreadPool(DefaultThreadPoolSupplier supplier) {
		this.subresources.defaultThreadPool = supplier.get();
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T timerThreadPool(TimerThreadPool value) {
		this.subresources.timerThreadPool = value;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T timerThreadPool(TimerThreadPoolConsumer consumer) {
		TimerThreadPool<? extends TimerThreadPool> child = new TimerThreadPool<>();
		if (consumer != null) {
			consumer.accept(child);
		}
		this.subresources.timerThreadPool = child;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T timerThreadPool() {
		TimerThreadPool<? extends TimerThreadPool> child = new TimerThreadPool<>();
		this.subresources.timerThreadPool = child;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T timerThreadPool(TimerThreadPoolSupplier supplier) {
		this.subresources.timerThreadPool = supplier.get();
		return (T) this;
	}

	/**
	 * Child mutators for Transport
	 */
	public static class TransportResources {
		/**
		 * A protocol property with name and value.
		 */
		private List<Property> properties = new java.util.ArrayList<>();
		private OobThreadPool oobThreadPool;
		private InternalThreadPool internalThreadPool;
		private DefaultThreadPool defaultThreadPool;
		private TimerThreadPool timerThreadPool;

		/**
		 * Get the list of Property resources
		 * 
		 * @return the list of resources
		 */
		@Subresource
		public List<Property> properties() {
			return this.properties;
		}

		public Property property(String key) {
			return this.properties.stream().filter(e -> e.getKey().equals(key))
					.findFirst().orElse(null);
		}
		/**
		 * A thread pool executor
		 */
		@Subresource
		public OobThreadPool oobThreadPool() {
			return this.oobThreadPool;
		}

		/**
		 * A thread pool executor
		 */
		@Subresource
		public InternalThreadPool internalThreadPool() {
			return this.internalThreadPool;
		}

		/**
		 * A thread pool executor
		 */
		@Subresource
		public DefaultThreadPool defaultThreadPool() {
			return this.defaultThreadPool;
		}

		/**
		 * A thread pool executor
		 */
		@Subresource
		public TimerThreadPool timerThreadPool() {
			return this.timerThreadPool;
		}
	}

	/**
	 * The diagnostics socket binding specification for this protocol layer,
	 * used to specify IP interfaces and ports for communication.
	 */
	@ModelNodeBinding(detypedName = "diagnostics-socket-binding")
	public String diagnosticsSocketBinding() {
		return this.diagnosticsSocketBinding;
	}

	/**
	 * The diagnostics socket binding specification for this protocol layer,
	 * used to specify IP interfaces and ports for communication.
	 */
	@SuppressWarnings("unchecked")
	public T diagnosticsSocketBinding(String value) {
		Object oldValue = this.diagnosticsSocketBinding;
		this.diagnosticsSocketBinding = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("diagnosticsSocketBinding", oldValue,
					value);
		return (T) this;
	}

	/**
	 * The machine (i.e. host) identifier for this node. Used by Infinispan
	 * topology-aware consistent hash.
	 */
	@ModelNodeBinding(detypedName = "machine")
	public String machine() {
		return this.machine;
	}

	/**
	 * The machine (i.e. host) identifier for this node. Used by Infinispan
	 * topology-aware consistent hash.
	 */
	@SuppressWarnings("unchecked")
	public T machine(String value) {
		Object oldValue = this.machine;
		this.machine = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("machine", oldValue, value);
		return (T) this;
	}

	/**
	 * The module with which to resolve the protocol type.
	 */
	@ModelNodeBinding(detypedName = "module")
	public String module() {
		return this.module;
	}

	/**
	 * The module with which to resolve the protocol type.
	 */
	@SuppressWarnings("unchecked")
	public T module(String value) {
		Object oldValue = this.module;
		this.module = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("module", oldValue, value);
		return (T) this;
	}

	/**
	 * The properties of this protocol.
	 */
	@ModelNodeBinding(detypedName = "properties")
	public Map properties() {
		return this.properties;
	}

	/**
	 * The properties of this protocol.
	 */
	@SuppressWarnings("unchecked")
	public T properties(Map value) {
		Object oldValue = this.properties;
		this.properties = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("properties", oldValue, value);
		return (T) this;
	}

	/**
	 * The properties of this protocol.
	 */
	@SuppressWarnings("unchecked")
	public T property(String key, Object value) {
		if (this.properties == null) {
			this.properties = new java.util.HashMap<>();
		}
		this.properties.put(key, value);
		return (T) this;
	}

	/**
	 * The rack (i.e. server rack) identifier for this node. Used by Infinispan
	 * topology-aware consistent hash.
	 */
	@ModelNodeBinding(detypedName = "rack")
	public String rack() {
		return this.rack;
	}

	/**
	 * The rack (i.e. server rack) identifier for this node. Used by Infinispan
	 * topology-aware consistent hash.
	 */
	@SuppressWarnings("unchecked")
	public T rack(String value) {
		Object oldValue = this.rack;
		this.rack = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("rack", oldValue, value);
		return (T) this;
	}

	/**
	 * The site (i.e. data centre) identifier for this node. Used by Infinispan
	 * topology-aware consistent hash.
	 */
	@ModelNodeBinding(detypedName = "site")
	public String site() {
		return this.site;
	}

	/**
	 * The site (i.e. data centre) identifier for this node. Used by Infinispan
	 * topology-aware consistent hash.
	 */
	@SuppressWarnings("unchecked")
	public T site(String value) {
		Object oldValue = this.site;
		this.site = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("site", oldValue, value);
		return (T) this;
	}

	/**
	 * The socket binding specification for this protocol layer, used to specify
	 * IP interfaces and ports for communication.
	 */
	@ModelNodeBinding(detypedName = "socket-binding")
	public String socketBinding() {
		return this.socketBinding;
	}

	/**
	 * The socket binding specification for this protocol layer, used to specify
	 * IP interfaces and ports for communication.
	 */
	@SuppressWarnings("unchecked")
	public T socketBinding(String value) {
		Object oldValue = this.socketBinding;
		this.socketBinding = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("socketBinding", oldValue, value);
		return (T) this;
	}
}

==> config-api-0.4.8-sources.jar: org/wildfly/swarm/config/jgroups/stack/Transport.java <==
package org.wildfly.swarm.config.jgroups.stack;

import org.wildfly.swarm.config.runtime.Address;
import java.util.HashMap;
import org.wildfly.swarm.config.runtime.ResourceType;
import java.beans.PropertyChangeSupport;
import java.beans.PropertyChangeListener;
import java.util.List;
import org.wildfly.swarm.config.runtime.Subresource;
import org.wildfly.swarm.config.jgroups.PropertyConsumer;
import org.wildfly.swarm.config.jgroups.PropertySupplier;
import org.wildfly.swarm.config.jgroups.Property;
import org.wildfly.swarm.config.jgroups.stack.transport.OobThreadPool;
import org.wildfly.swarm.config.jgroups.stack.transport.OobThreadPoolConsumer;
import org.wildfly.swarm.config.jgroups.stack.transport.OobThreadPoolSupplier;
import org.wildfly.swarm.config.jgroups.stack.transport.InternalThreadPool;
import org.wildfly.swarm.config.jgroups.stack.transport.InternalThreadPoolConsumer;
import org.wildfly.swarm.config.jgroups.stack.transport.InternalThreadPoolSupplier;
import org.wildfly.swarm.config.jgroups.stack.transport.DefaultThreadPool;
import org.wildfly.swarm.config.jgroups.stack.transport.DefaultThreadPoolConsumer;
import org.wildfly.swarm.config.jgroups.stack.transport.DefaultThreadPoolSupplier;
import org.wildfly.swarm.config.jgroups.stack.transport.TimerThreadPool;
import org.wildfly.swarm.config.jgroups.stack.transport.TimerThreadPoolConsumer;
import org.wildfly.swarm.config.jgroups.stack.transport.TimerThreadPoolSupplier;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import java.util.Map;

/**
 * The configuration of a transport for a protocol stack.
 */
@Address("/subsystem=jgroups/stack=*/transport=*")
@ResourceType("transport")
public class Transport<T extends Transport<T>> extends HashMap {

	private String key;
	private PropertyChangeSupport pcs;
	private TransportResources subresources = new TransportResources();
	private String diagnosticsSocketBinding;
	private String machine;
	private String module;
	private Map properties;
	private String rack;
	private String site;
	private String socketBinding;

	public Transport(java.lang.String key) {
		super();
		this.key = key;
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * Adds a property change listener
	 */
	public void addPropertyChangeListener(PropertyChangeListener listener) {
		if (null == this.pcs)
			this.pcs = new PropertyChangeSupport(this);
		this.pcs.addPropertyChangeListener(listener);
	}

	/**
	 * Removes a property change listener
	 */
	public void removePropertyChangeListener(
			java.beans.PropertyChangeListener listener) {
		if (this.pcs != null)
			this.pcs.removePropertyChangeListener(listener);
	}

	public TransportResources subresources() {
		return this.subresources;
	}

	/**
	 * Add all Property objects to this subresource
	 * 
	 * @return this
	 * @param value
	 *            List of Property objects.
	 */
	@SuppressWarnings("unchecked")
	public T properties(java.util.List<Property> value) {
		this.subresources.properties = value;
		return (T) this;
	}

	/**
	 * Add the Property object to the list of subresources
	 * 
	 * @param value
	 *            The Property to add
	 * @return this
	 */
	@SuppressWarnings("unchecked")
	public T property(Property value) {
		this.subresources.properties.add(value);
		return (T) this;
	}

	/**
	 * Create and configure a Property object to the list of subresources
	 * 
	 * @param key
	 *            The key for the Property resource
	 * @param config
	 *            The PropertyConsumer to use
	 * @return this
	 */
	@SuppressWarnings("unchecked")
	public T property(java.lang.String childKey, PropertyConsumer consumer) {
		Property<? extends Property> child = new Property<>(childKey);
		if (consumer != null) {
			consumer.accept(child);
		}
		property(child);
		return (T) this;
	}

	/**
	 * Create and configure a Property object to the list of subresources
	 * 
	 * @param key
	 *            The key for the Property resource
	 * @return this
	 */
	@SuppressWarnings("unchecked")
	public T property(java.lang.String childKey) {
		property(childKey, null);
		return (T) this;
	}

	/**
	 * Install a supplied Property object to the list of subresources
	 */
	@SuppressWarnings("unchecked")
	public T property(PropertySupplier supplier) {
		property(supplier.get());
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T oobThreadPool(OobThreadPool value) {
		this.subresources.oobThreadPool = value;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T oobThreadPool(OobThreadPoolConsumer consumer) {
		OobThreadPool<? extends OobThreadPool> child = new OobThreadPool<>();
		if (consumer != null) {
			consumer.accept(child);
		}
		this.subresources.oobThreadPool = child;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T oobThreadPool() {
		OobThreadPool<? extends OobThreadPool> child = new OobThreadPool<>();
		this.subresources.oobThreadPool = child;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T oobThreadPool(OobThreadPoolSupplier supplier) {
		this.subresources.oobThreadPool = supplier.get();
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T internalThreadPool(InternalThreadPool value) {
		this.subresources.internalThreadPool = value;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T internalThreadPool(InternalThreadPoolConsumer consumer) {
		InternalThreadPool<? extends InternalThreadPool> child = new InternalThreadPool<>();
		if (consumer != null) {
			consumer.accept(child);
		}
		this.subresources.internalThreadPool = child;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T internalThreadPool() {
		InternalThreadPool<? extends InternalThreadPool> child = new InternalThreadPool<>();
		this.subresources.internalThreadPool = child;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T internalThreadPool(InternalThreadPoolSupplier supplier) {
		this.subresources.internalThreadPool = supplier.get();
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T defaultThreadPool(DefaultThreadPool value) {
		this.subresources.defaultThreadPool = value;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T defaultThreadPool(DefaultThreadPoolConsumer consumer) {
		DefaultThreadPool<? extends DefaultThreadPool> child = new DefaultThreadPool<>();
		if (consumer != null) {
			consumer.accept(child);
		}
		this.subresources.defaultThreadPool = child;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T defaultThreadPool() {
		DefaultThreadPool<? extends DefaultThreadPool> child = new DefaultThreadPool<>();
		this.subresources.defaultThreadPool = child;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T defaultThreadPool(DefaultThreadPoolSupplier supplier) {
		this.subresources.defaultThreadPool = supplier.get();
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T timerThreadPool(TimerThreadPool value) {
		this.subresources.timerThreadPool = value;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T timerThreadPool(TimerThreadPoolConsumer consumer) {
		TimerThreadPool<? extends TimerThreadPool> child = new TimerThreadPool<>();
		if (consumer != null) {
			consumer.accept(child);
		}
		this.subresources.timerThreadPool = child;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T timerThreadPool() {
		TimerThreadPool<? extends TimerThreadPool> child = new TimerThreadPool<>();
		this.subresources.timerThreadPool = child;
		return (T) this;
	}

	/**
	 * A thread pool executor
	 */
	@SuppressWarnings("unchecked")
	public T timerThreadPool(TimerThreadPoolSupplier supplier) {
		this.subresources.timerThreadPool = supplier.get();
		return (T) this;
	}

	/**
	 * Child mutators for Transport
	 */
	public static class TransportResources {
		/**
		 * A protocol property with name and value.
		 */
		private List<Property> properties = new java.util.ArrayList<>();
		private OobThreadPool oobThreadPool;
		private InternalThreadPool internalThreadPool;
		private DefaultThreadPool defaultThreadPool;
		private TimerThreadPool timerThreadPool;

		/**
		 * Get the list of Property resources
		 * 
		 * @return the list of resources
		 */
		@Subresource
		public List<Property> properties() {
			return this.properties;
		}

		public Property property(java.lang.String key) {
			return this.properties.stream().filter(e -> e.getKey().equals(key))
					.findFirst().orElse(null);
		}
		/**
		 * A thread pool executor
		 */
		@Subresource
		public OobThreadPool oobThreadPool() {
			return this.oobThreadPool;
		}

		/**
		 * A thread pool executor
		 */
		@Subresource
		public InternalThreadPool internalThreadPool() {
			return this.internalThreadPool;
		}

		/**
		 * A thread pool executor
		 */
		@Subresource
		public DefaultThreadPool defaultThreadPool() {
			return this.defaultThreadPool;
		}

		/**
		 * A thread pool executor
		 */
		@Subresource
		public TimerThreadPool timerThreadPool() {
			return this.timerThreadPool;
		}
	}

	/**
	 * The diagnostics socket binding specification for this protocol layer,
	 * used to specify IP interfaces and ports for communication.
	 */
	@ModelNodeBinding(detypedName = "diagnostics-socket-binding")
	public String diagnosticsSocketBinding() {
		return this.diagnosticsSocketBinding;
	}

	/**
	 * The diagnostics socket binding specification for this protocol layer,
	 * used to specify IP interfaces and ports for communication.
	 */
	@SuppressWarnings("unchecked")
	public T diagnosticsSocketBinding(java.lang.String value) {
		Object oldValue = this.diagnosticsSocketBinding;
		this.diagnosticsSocketBinding = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("diagnosticsSocketBinding", oldValue,
					value);
		return (T) this;
	}

	/**
	 * The machine (i.e. host) identifier for this node. Used by Infinispan
	 * topology-aware consistent hash.
	 */
	@ModelNodeBinding(detypedName = "machine")
	public String machine() {
		return this.machine;
	}

	/**
	 * The machine (i.e. host) identifier for this node. Used by Infinispan
	 * topology-aware consistent hash.
	 */
	@SuppressWarnings("unchecked")
	public T machine(java.lang.String value) {
		Object oldValue = this.machine;
		this.machine = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("machine", oldValue, value);
		return (T) this;
	}

	/**
	 * The module with which to resolve the protocol type.
	 */
	@ModelNodeBinding(detypedName = "module")
	public String module() {
		return this.module;
	}

	/**
	 * The module with which to resolve the protocol type.
	 */
	@SuppressWarnings("unchecked")
	public T module(java.lang.String value) {
		Object oldValue = this.module;
		this.module = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("module", oldValue, value);
		return (T) this;
	}

	/**
	 * The properties of this protocol.
	 */
	@ModelNodeBinding(detypedName = "properties")
	public Map properties() {
		return this.properties;
	}

	/**
	 * The properties of this protocol.
	 */
	@SuppressWarnings("unchecked")
	public T properties(java.util.Map value) {
		Object oldValue = this.properties;
		this.properties = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("properties", oldValue, value);
		return (T) this;
	}

	/**
	 * The properties of this protocol.
	 */
	@SuppressWarnings("unchecked")
	public T property(java.lang.String key, java.lang.Object value) {
		if (this.properties == null) {
			this.properties = new java.util.HashMap<>();
		}
		this.properties.put(key, value);
		return (T) this;
	}

	/**
	 * The rack (i.e. server rack) identifier for this node. Used by Infinispan
	 * topology-aware consistent hash.
	 */
	@ModelNodeBinding(detypedName = "rack")
	public String rack() {
		return this.rack;
	}

	/**
	 * The rack (i.e. server rack) identifier for this node. Used by Infinispan
	 * topology-aware consistent hash.
	 */
	@SuppressWarnings("unchecked")
	public T rack(java.lang.String value) {
		Object oldValue = this.rack;
		this.rack = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("rack", oldValue, value);
		return (T) this;
	}

	/**
	 * The site (i.e. data centre) identifier for this node. Used by Infinispan
	 * topology-aware consistent hash.
	 */
	@ModelNodeBinding(detypedName = "site")
	public String site() {
		return this.site;
	}

	/**
	 * The site (i.e. data centre) identifier for this node. Used by Infinispan
	 * topology-aware consistent hash.
	 */
	@SuppressWarnings("unchecked")
	public T site(java.lang.String value) {
		Object oldValue = this.site;
		this.site = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("site", oldValue, value);
		return (T) this;
	}

	/**
	 * The socket binding specification for this protocol layer, used to specify
	 * IP interfaces and ports for communication.
	 */
	@ModelNodeBinding(detypedName = "socket-binding")
	public String socketBinding() {
		return this.socketBinding;
	}

	/**
	 * The socket binding specification for this protocol layer, used to specify
	 * IP interfaces and ports for communication.
	 */
	@SuppressWarnings("unchecked")
	public T socketBinding(java.lang.String value) {
		Object oldValue = this.socketBinding;
		this.socketBinding = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("socketBinding", oldValue, value);
		return (T) this;
	}
}
